==> haskell-yaml-0.11.11.2-197.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-yaml.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 yaml
version:              0.11.11.2
visibility:           public
id:                   yaml-0.11.11.2-GyIObvMByN0941lpfsiwCu
key:                  yaml-0.11.11.2-GyIObvMByN0941lpfsiwCu
license:              BSD-3-Clause
maintainer:           Michael Snoyman <michael@snoyman.com>
author:
    Michael Snoyman <michael@snoyman.com>, Anton Ageev <antage@gmail.com>,Kirill Simonov

stability:            stable
homepage:             https://github.com/snoyberg/yaml#readme
synopsis:             Support for parsing and rendering YAML documents.
description:
    README and API documentation are available at <https://www.stackage.org/package/yaml>

category:             Data
abi:                  d1fd0a9168e73a1d7f1748e1d5f71d24
exposed:              True
exposed-modules:
    Data.Yaml Data.Yaml.Aeson Data.Yaml.Builder Data.Yaml.Config
    Data.Yaml.Include Data.Yaml.Internal Data.Yaml.Parser
    Data.Yaml.Pretty Data.Yaml.TH

hidden-modules:       Paths_yaml
import-dirs:          /usr/lib/ghc-9.6.6/site-local/yaml-0.11.11.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/yaml-0.11.11.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/yaml-0.11.11.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-yaml
hs-libraries:         HSyaml-0.11.11.2-GyIObvMByN0941lpfsiwCu
depends:
    aeson-2.1.2.1-GojnAvr1Jep10WUNi5H1Pi
    attoparsec-0.14.4-8gkbEkDkw506qTMOo0v2nm base-4.18.2.1
    bytestring-0.11.5.3 conduit-1.3.6.1-252yfbtdylIFaQqQ0JKO9q
    containers-0.6.7 directory-1.3.8.5 filepath-1.4.300.1
    libyaml-0.1.4-BUBBxYwvUBe2CVGVwDzHtA mtl-2.3.1
    resourcet-1.2.6-BDQ4bs2ZkKrFMSf2ISkWBx
    scientific-0.3.8.0-3zIJLnW8aJ66FNwcOaEmTV template-haskell-2.20.0.0
    text-2.0.2 transformers-0.6.1.0
    unordered-containers-0.2.20.1-50qrTxmoJy9AxZ7OdMnycu
    vector-0.13.2.0-L5lYsWFgdBEAgjlr9nnpMP

haddock-interfaces:   /usr/share/doc/haskell-yaml/html/yaml.haddock
haddock-html:         /usr/share/doc/haskell-yaml/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-yaml-0.11.11.2-198-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-yaml.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 yaml
version:              0.11.11.2
visibility:           public
id:                   yaml-0.11.11.2-HJgRwey6BMIIq0hOFQKRBa
key:                  yaml-0.11.11.2-HJgRwey6BMIIq0hOFQKRBa
license:              BSD-3-Clause
maintainer:           Michael Snoyman <michael@snoyman.com>
author:
    Michael Snoyman <michael@snoyman.com>, Anton Ageev <antage@gmail.com>,Kirill Simonov

stability:            stable
homepage:             https://github.com/snoyberg/yaml#readme
synopsis:             Support for parsing and rendering YAML documents.
description:
    README and API documentation are available at <https://www.stackage.org/package/yaml>

category:             Data
abi:                  43f1be289792d46c0be4c6ffef92992e
exposed:              True
exposed-modules:
    Data.Yaml Data.Yaml.Aeson Data.Yaml.Builder Data.Yaml.Config
    Data.Yaml.Include Data.Yaml.Internal Data.Yaml.Parser
    Data.Yaml.Pretty Data.Yaml.TH

hidden-modules:       Paths_yaml
import-dirs:          /usr/lib/ghc-9.6.6/site-local/yaml-0.11.11.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/yaml-0.11.11.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/yaml-0.11.11.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-yaml
hs-libraries:         HSyaml-0.11.11.2-HJgRwey6BMIIq0hOFQKRBa
depends:
    aeson-2.1.2.1-CpIoOLI7lIpJkSqSOmDN9y
    attoparsec-0.14.4-68EOoedQqwu8mpKj0RmtvE base-4.18.2.1
    bytestring-0.11.5.3 conduit-1.3.6.1-5afbFXdQmpuHK8N5OCErlh
    containers-0.6.7 directory-1.3.8.5 filepath-1.4.300.1
    libyaml-0.1.4-FqSNdc5sCXQ59Bccr5psT6 mtl-2.3.1
    resourcet-1.2.6-7GW6wEwAkCf499WYv26LMs
    scientific-0.3.8.0-JR5ijS18eRDLRLPoHGHkyW template-haskell-2.20.0.0
    text-2.0.2 transformers-0.6.1.0
    unordered-containers-0.2.20.1-L0jiELAFLwP1g4FZscm3B5
    vector-0.13.2.0-eGaPlIkScLKlfBYQuI3vH

haddock-interfaces:   /usr/share/doc/haskell-yaml/html/yaml.haddock
haddock-html:         /usr/share/doc/haskell-yaml/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
